@@ -1,5 +1,5 @@
 freqdom.lags = function(X){
-  if (is.timedom(X))
+  if (is.null(X$freq))
     lags = X$lags
   else
     lags = X$freq
